==> google_appengine_1.9.73.zip: google_appengine/google/appengine/tools/devappserver2/admin/console.py <==
#!/usr/bin/env python
#
# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
"""A handler that provides an interactive console."""



import threading

from google.appengine.tools.devappserver2 import module
from google.appengine.tools.devappserver2.admin import admin_request_handler


class ConsoleRequestHandler(admin_request_handler.AdminRequestHandler):
  """Provides an interactive console for modules that support it."""

  _modulename_to_shell_module = {}
  _modulename_to_shell_module_lock = threading.Lock()

  def get(self):
    super(ConsoleRequestHandler, self).get()
    self.response.write(
        self.render('console.html',
                    {'modules': [modul for modul in self.dispatcher.modules
                                 if modul.supports_interactive_commands]}))

  def post(self):
    super(ConsoleRequestHandler, self).post()

    if not self.enable_console:
      self.response.status = 404
      self.response.write('The interactive console is currently disabled. '
                          'To enable the console, invoke dev_appserver.py '
                          'with the --enable_console argument.')
      return

    module_name = self.request.get('module_name')
    with self._modulename_to_shell_module_lock:
      if module_name in self._modulename_to_shell_module:
        modul = self._modulename_to_shell_module[module_name]
      else:
        modul = self.dispatcher.get_module_by_name(
            module_name).create_interactive_command_module()
        self._modulename_to_shell_module[module_name] = modul

    self.response.content_type = 'text/plain'
    try:
      response = modul.send_interactive_command(self.request.get('code'))
    except module.InteractiveCommandError, e:
      response = str(e)

    self.response.write(response)

  @classmethod
  def quit(cls):
    with cls._modulename_to_shell_module_lock:
      for shell_module in cls._modulename_to_shell_module.itervalues():
        shell_module.quit()

  @classmethod
  def restart(cls, request, module_name):
    with cls._modulename_to_shell_module_lock:
      if module_name in cls._modulename_to_shell_module:
        modul = cls._modulename_to_shell_module[module_name]
        modul.restart()

==> google_appengine_1.9.91.zip: google_appengine/google/appengine/tools/devappserver2/admin/console.py <==
#!/usr/bin/env python
#
# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
"""A handler that provides an interactive console."""



import threading

from google.appengine.tools.devappserver2 import module
from google.appengine.tools.devappserver2.admin import admin_request_handler


class ConsoleRequestHandler(admin_request_handler.AdminRequestHandler):
  """Provides an interactive console for modules that support it."""

  _modulename_to_shell_module = {}
  _modulename_to_shell_module_lock = threading.Lock()

  def get(self):
    super(ConsoleRequestHandler, self).get()
    self.response.write(
        self.render('console.html',
                    {'modules': [modul for modul in self.dispatcher.modules
                                 if modul.supports_interactive_commands]}))

  def post(self):
    super(ConsoleRequestHandler, self).post()

    if not self.enable_console:
      self.response.status = 404
      self.response.write('The interactive console is currently disabled. '
                          'To enable the console, invoke dev_appserver.py '
                          'with the --enable_console argument.')
      return

    module_name = self.request.get('module_name')
    with self._modulename_to_shell_module_lock:
      if module_name in self._modulename_to_shell_module:
        modul = self._modulename_to_shell_module[module_name]
      else:
        modul = self.dispatcher.get_module_by_name(
            module_name).create_interactive_command_module()
        self._modulename_to_shell_module[module_name] = modul

    self.response.content_type = 'text/plain'
    try:
      response = modul.send_interactive_command(self.request.get('code'))
    except module.InteractiveCommandError as e:
      response = str(e)

    self.response.write(response)

  @classmethod
  def quit(cls):
    with cls._modulename_to_shell_module_lock:
      for shell_module in cls._modulename_to_shell_module.itervalues():
        shell_module.quit()

  @classmethod
  def restart(cls, request, module_name):
    with cls._modulename_to_shell_module_lock:
      if module_name in cls._modulename_to_shell_module:
        modul = cls._modulename_to_shell_module[module_name]
        modul.restart()
